SystemManagerG_install_agent
============================

Description
-----------

This role installs SystemManager G agents and logical system agents. The user can install an agent by creating an archive for installation from MasterScope Media and storing it in the location specified with this role.

Requirements
------------

* This role must be executed on the server to be built with administrator authority. In Windows, create a playbook to execute this role as the user with administrator authority on the server to be built. In RHEL, create a playbook to execute this role as the root user on the server to be built.
* In RHEL, check and install the OS package required to operate the product by using the yum module in Ansible. Configure one of the following settings in advance. For details about the OS package, see "SystemManager G Release Memo".
 * Install the OS package required on the server to be built in advance.
 * Appropriately set the yum repository on the server to be built and execute the yum command so that the necessary OS package can be installed.

Notes
-----

* This role can not use an agent upgrade.
* In RHEL, ncompress or gzip is required as the package required to operate the agent. This role checks and installs gzip.
* MasterScope Media Release Memo describes notes on installation. See this release memo with this document.

Role Variables
--------------

The variables used with this role (defaults/main.yml) are described below.

### Mandatory variables

Be sure to specify the following variables when executing this role.

#### VAR_SystemManagerG_agent_install_type

Specify the type of agent to be installed.
Specify normal to install an agent.
Specify logical to install a logical system agent.

#### VAR_SystemManagerG_manager_name

Specify the manager host name.
Specify this value by using no more than 64 characters.
Multi-byte characters such as Japanese cannot be specified.

### Optional variables

Optionally specify the following variables.

#### VAR_SystemManagerG_agent_install_path

Specify the agent installation destination (installation path).
Specify this value by using no more than 128 characters.
This value cannot contain multi-byte characters such as Japanese.

If this variable is omitted, the following path is the installation location.

* Agent
 * For Windows: %ProgramFiles(x86)%\NEC\UMF\Operations
 * For RHEL: /opt/UMF/Operations

* Logical system agent
 * For Windows: %ProgramFiles(x86)%\NEC\UMF\OperationsLogical
 * For RHEL: /opt/UMF/OperationsLogical

#### VAR_SystemManagerG_agent_name

Specify the name of the local host of the agent.
Specify this value by using no more than 64 characters.
Multi-byte characters such as Japanese cannot be specified.

If this variable is omitted, the following value is set.

* For Windows: Value of the environment variable %COMPUTERNAME%
* For RHEL: Value displayed by running the hostname command

#### VAR_SystemManagerG_agent_port

Specify the port for agent internal communication.
Specify a value from 1024 to 65535.

If this variable is omitted, 12570 is set.

#### VAR_SystemManagerG_agent_data_directory

Specify the data directory to divide the data area.
Specify this value by using no more than 128 characters.
This value cannot contain multi-byte characters such as Japanese.

This variable can be specified only for a logical system agent.
If this variable is omitted, the data area is not divided.

#### VAR_SystemManagerG_agent_store_initial_setting_data

Specify whether to install initial data in the data area.
Specify 0 to install initial data.
Specify 1 not to install initial data.

This variable can be specified only for a logical system agent.
If this variable is omitted, initial data is installed.

#### VAR_SystemManagerG_agent_service_identifier

Specify the value to identify services for multi-instance products.
Specify this value by using no more than 16 characters.

It is not necessary to specify this variable in single-instance configuration.
It is required to specify this variable in multi-instance configuration.

#### VAR_SystemManagerG_agent_service_number

Specify the number to be added to the service name.
Specify a value from 1 to 999.

If this variable is omitted, a number is automatically set during installation.

#### VAR_SystemManagerG_manager_port

Specify the port for communication with the manager.
Specify a value from 1024 to 65535.

If this variable is omitted, 12520 is set.

#### VAR_SystemManagerG_agent_topology_group

Specify the group name of topology view in which the agent is registered.
When completely installed, the agent is registered in the group with the specified name.
Multi-byte characters such as Japanese can be specified.

The group name to be specified must exist in the topology view in advance.
Create the group in the topology view in advance.
The group name must be unique in the topology view.

If this variable is omitted, the agent is registered in "Unregistered Host" in the topology view.

Example of registering an agent in GroupA

    + Topology view
      + GroupA
      + GroupB
      + GroupC

    VAR_SystemManagerG_agent_group: GroupA

Specify only the name of the group in which the agent is registered even in a hierarchical configuration.

Example of registering an agent in GroupC

    + Topology view
      + GroupA
        + GroupB
          + GroupC

    VAR_SystemManagerG_agent_group: GroupC


#### VAR_SystemManagerG_tmp_path

You can specify the temporary work directory used by this role.
The temporary work directory must have a free disk space to store the archive for installation (in files for this role).

Specify this value by using no more than 128 characters.
This value cannot contain multi-byte characters such as Japanese.

The specified directory is automatically created if it does not exist.
If this role normally terminates, the directory is automatically deleted.

If this variable is omitted, the following directory is used:

* For Windows: %TEMP%\sysmgrg_ansible
* For RHEL: /tmp/sysmgrg_ansible

Dependencies
------------

None

Usage
-----

1) Enable the function to register the agent in the specified group in the topology view. Add information to the following configuration file:

* Location of configuration file
    <Manager installation path>/Manager/sg/TopologyMgr.ini

* Description details
  Add the following two lines:

    [Automation]
    Remake=0

* If the configuration file does not exist, create a new one.
* For Windows, use the character encoding "UTF-16LE (with BOM)" and the line feed code "CR+LF" in the configuration file. * For RHEL, use the character encoding "UTF-8 (without BOM)" and the line feed code "LF" in the configuration file.
* Restarting of the manager is not required after adding information to the configuration file.
* This procedure is not required if you do not use the function to register the agent in the specified group in the topology view.

2) Create the archive for installing the agent from the MasterScope Media.

* For the following creation procedure, it is assumed that MasterScope Media is mounted to /media and /tmp is used as the work directory.
* When creating the archive for installing the Windows agent, execute the next command on Linux and create Windows.zip.

    $ cd /tmp
    $ mkdir -p ./Windows/Product/UMF/PRODUCT
    $ cp -rfp /media/Windows/Product/UMF/SETUP ./Windows/Product/UMF
    $ cp -rfp /media/Windows/Product/UMF/SYSTEM ./Windows/Product/UMF
    $ cp -rfp /media/Windows/Product/UMF/FRAMEWORK ./Windows/Product/UMF
    $ cp -rfp /media/Windows/Product/UMF/PRODUCT/Product100 ./Windows/Product/UMF/PRODUCT
    $ cp -rfp /media/Windows/Product/UMF/PRODUCT/Product200 ./Windows/Product/UMF/PRODUCT
    $ zip Windows.zip -r Windows

* When creating the archive for installing the RHEL agent, execute the next command on Linux and create Linux.tar.

    $ cd /tmp
    $ mkdir -p ./Linux/Product/UMF/PRODUCT
    $ cp -rfp /media/Linux/Product/UMF/SETUP ./Linux/Product/UMF
    $ cp -rfp /media/Linux/Product/UMF/FRAMEWORK ./Linux/Product/UMF
    $ cp -rfp /media/Linux/Product/UMF/PRODUCT/Product100 ./Linux/Product/UMF/PRODUCT
    $ cp -rfp /media/Linux/Product/UMF/PRODUCT/Product200 ./Linux/Product/UMF/PRODUCT
    $ tar cvf Linux.tar Linux

3) Store the archive for installation in the files directory for this role.

    SystemManagerG_install_agent
    |- files
    |  |- Windows.zip
    |  |- Linux.tar

4) For SystemManager G 9.1 or earlier agent, manually overwrite the files stored in the following [Source] with [Destination].

    [Source]
     SystemManagerG_install_agent/vars/sysmgrg9.1/RedHat-6.yml
     SystemManagerG_install_agent/vars/sysmgrg9.1/RedHat-7.yml

    [Destination]
     SystemManagerG_install_agent/vars/RedHat-6.yml
     SystemManagerG_install_agent/vars/RedHat-7.yml

5) Set the required variables for this role. For details, see "Role Variables".
6) Set optional variables for this role as needed. For details, see "Role Variables".
7) Execute a playbook.

Sample Playbook
----------------

Store the provided role in the "roles" directory and create the playbook described below.

    - hosts: AgentServers
      vars_files:
        - vars/main.yml
      roles:
        - role: SystemManagerG_install_agent

Contents of vars/main.yml

    VAR_SystemManagerG_agent_install_type: normal
    VAR_SystemManagerG_manager_name: ManagerServer
    VAR_SystemManagerG_agent_topology_group: GroupA

Restrictions
------------

* Execution may fail if the same playbook contains this role and the role of SystemManagerG_setup_agent-ApplicationMonitoring-XXX (XXX is the middleware name). Specify them in different playbooks and separately execute them.

Troubleshooting
---------------

#### TASK [Check os family] fails.

If "This OS is not supported." is displayed, the server to be built uses an unsupported OS.

#### TASK [Create the temporary directory] fails.

It failed to create the temporary work directory specified with VAR_SystemManagerG_tmp_path.
Check whether the specified path is correct.

#### TASK [Check the agent installation status] fails.

If "The agent is already installed in the installation directory" is displayed, the agent is already installed in the path specified with VAR_SystemManagerG_agent_install_path (default value if no path is specified).

License
-------

Use this role within the scope of license of the main product.

Copyright
---------

Copyright (c) NEC Corporation 2017
