SystemManagerG_setup_agent-ApplicationMonitor-Oracle
=================================================

Description
-----------

This role sets to monitor agents registered in the topology view in SystemManager G with Oracle. The user can store the setting in the location specified by this role and execute it for the agent server to set to monitor agents with Oracle.

Requirements
------------

* This role must be executed on the server to be built with administrator authority. In Windows, create a playbook to execute this role as the user with administrator authority on the server to be built. In RHEL, create a playbook to execute this role as the root user on the server to be built.
* It is necessary to install Oracle Database on the server to be built in advance. Oracle Client may have to be installed in some environments. For details, see the help manual of SystemManager G.

Notes
-----

* Execute this role for the SystemManager G Oracle monitoring agent server.
* This role connects to the Oracle instance for the monitoring setting. Therefore, hosts where the Oracle instance is not started cannot be set to be monitored.

Role Variables
--------------

The variables used with this role are described below.
Use a playbook to specify the variables described in "Mandatory variables" and "Optional variables".

### Mandatory variables

Be sure to specify the following variables when executing this role.

#### VAR_SystemManagerG_ENV_ORACLE_HOME

Specify the Oracle home directory to be set to the environment variable: ORACLE_HOME.

#####  windows

Specify the folder name for Windows.

#####  linux

Specify the folder name for Linux.

#### VAR_SystemManagerG_ENV_ORACLE_SID

Specify the Oracle SID to be set to the environment variable: ORACLE_SID.

#### VAR_SystemManagerG_oracle_user_name

Specify the owner user name of the Oracle Database file.

#### VAR_SystemManagerG_agent_oracle_tnsnames_file_path

Specify the name of the folder that contains the tnsnames.ora file.

#####  windows

Specify the folder name for Windows.

#####  linux

Specify the folder name for Linux.

#### VAR_SystemManagerG_Oracle_Login_User_Name

Specify the name of the user who connects to Oracle Database.

#### VAR_SystemManagerG_Oracle_Login_Password

Specify the password of the user who connects to Oracle Database.

#### VAR_SystemManagerG_Oracle_Network_Service_Name

Specify the name of the network service for Oracle Database.

#### VAR_SystemManagerG_Oracle_Monitoring_User_Password

Specify the password of the user who monitors Oracle Database dedicated to SystemManager G.

#### VAR_SystemManagerG_Oracle_Monitoring_Datafile_of_Tablespace

Specify the full path name of the table area file for the user dedicated to SystemManager G.

#### VAR_SystemManagerG_Oracle_Monitoring_Temporary_Tablespace_Name

Specify the name of the existing temporary table area file for the user dedicated to SystemManager G.
Nonexistent temporary table area files cannot be specified.

### Optional variables

Specify parameters as needed.

#### VAR_SystemManagerG_Oracle_Monitoring_User_Name

Specify the name of the user who monitors Oracle Database dedicated to SystemManager G.
If this is omitted, SYSMGRG is set.

#### VAR_SystemManagerG_Oracle_Monitoring_Tablespace_Name

Specify the name of the default table area name for the user dedicated to SystemManager G.
If this is omitted, SYSMGRG is set.

#### VAR_SystemManagerG_agent_install_path

Specify the agent installation destination (installation path).

#####  windows

Specify the folder name for Windows.
If this is omitted, C:\Program Files (x86)\NEC\UMF\Operations is set.

#####  linux

Specify the folder name for Linux.
If this is omitted, /opt/UMF/Operations is set.

### Unchangeable variable

This parameter cannot be changed.

#### VAR_SystemManagerG_agent_collector_ini_file_name

This is the name of the configuration file for the Oracle Database monitoring function. This file cannot be renamed.
The name is fixed to CollectorOracle.ini.

#### VAR_SystemManagerG_agent_collector_oracle_config

This is the name of the configuration file for the application monitoring function. This file cannot be renamed.
The name is fixed to config.

#### VAR_SystemManagerG_agent_oracle_tnsnames_file_name

This is the name of the Oracle Database network configuration file. This file cannot be renamed.
The name is fixed to tnsnames.ora.

Dependencies
------------

SystemManagerG_common_agent_service_restart is used as the dependent role.

Usage
-----

1. Store the Oracle monitoring definition file/Oracle configuration file/setup script in the files/linux or files/windows directory for this role. When applying the monitoring definition file to the Windows agent, create it using the "character encoding: UTF-16LE (with BOM)/line feed code: CR+LF". When applying the monitoring definition file to the RHEL agent, create it using the "character encoding: UTF-8 (without BOM)/line feed code: LF".
The Oracle configuration file/setup script must have the same character encoding and line feed code as those in the file on the target host.
When it's necessary to apply the Oracle network configuration file, Store in the files/linux or files/windows directory for this role.
The Oracle network configuration file must have the same character encoding and line feed code as those in the file on the target host.

    SystemManagerG_setup_agent-ApplicationMonitor-Oracle
    |- files
    |  |- linux
    |  |  |- CollectorOracle.ini
    |  |  |- config
    |  |  |- OracleSetupArgument.sql
    |  |  |- tnsnames.ora
    |  |- windows
    |  |  |- CollectorOracle.ini
    |  |  |- OracleSetupArgument.sql
    |  |  |- tnsnames.ora
    |  |  |- ...

2. Specify the agent installation folder name according to the OS type of target host.

3. Set the required variables for this role. For details, see "Role Variables".

4. Set optional variables for this role as needed. For details, see "Role Variables".

5. Execute a playbook.

Example Playbook
----------------

To install an agent and import the monitoring setting, store the provided role in the "role" directory and create the playbook described below.

    - hosts: monitoring_oracle
      roles:
        - role: SystemManagerG_setup_agent-ApplicationMonitor-Oracle

Troubleshooting
---------------

None

License
-------

Use this role within the scope of license of the main product.

Copyright
---------

Copyright (c) NEC Corporation 2017
