/*
//////////////////////////////////////////////////////////////////////
  OracleSetup.sql

  This is a part of the WebSAM Application Navigator.
  Copyright (C) 2011 NEC Corporation.
  All rights reserved.

  - Modification is not granted at any reason.
  - Exhibit, publication, disclosure is not granted.
//////////////////////////////////////////////////////////////////////
*/

SET ECHO OFF
SET VERIFY OFF
SET SERVEROUTPUT ON SIZE 20000

DECLARE

s_user_name			VARCHAR2(256);
s_password			VARCHAR2(256);
s_tablespace_name	VARCHAR2(256);
s_datafile_name		VARCHAR2(256);
s_tmpspace_name		VARCHAR2(256);
s_profile_name			VARCHAR2(256);
n_cnt				PLS_INTEGER;
b_create_tablespace	BOOLEAN;

TYPE table_data IS RECORD (table_name VARCHAR(32), column_name VARCHAR(64));
TYPE str_array IS TABLE OF table_data INDEX BY PLS_INTEGER;
table_array str_array;

--------------------------------------------------------------------------------
-- PROCEDURE create_tablespace
--------------------------------------------------------------------------------
PROCEDURE create_tablespace
IS
	s_sql VARCHAR2(1024);

BEGIN
	s_sql := 'CREATE TABLESPACE '
		|| s_tablespace_name
		|| ' DATAFILE ''' 
		|| s_datafile_name
		|| ''' SIZE 10M AUTOEXTEND OFF';
	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created tablespace ''' || s_tablespace_name || '''.');

END;

--------------------------------------------------------------------------------
-- PROCEDURE create_user
--------------------------------------------------------------------------------
PROCEDURE create_user
IS
	TYPE str_array IS TABLE OF VARCHAR2(64) INDEX BY PLS_INTEGER;
	auth_array str_array;
	s_sql VARCHAR2(1024);
	n_loop_cnt PLS_INTEGER;

BEGIN
	-- create profile --
	s_sql := 'CREATE PROFILE '
		|| s_profile_name
		|| ' LIMIT PASSWORD_LIFE_TIME UNLIMITED';
	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created profile ''' || s_profile_name || '''.');

	-- create user --
	IF s_tmpspace_name IS NULL THEN
		s_sql := 'CREATE USER '
			|| s_user_name
			|| ' IDENTIFIED BY '
			|| s_password
			|| ' DEFAULT TABLESPACE '
			|| s_tablespace_name
			|| ' QUOTA UNLIMITED ON '
			|| s_tablespace_name
			|| ' PROFILE '
			|| s_profile_name;
	ELSE
		s_sql := 'CREATE USER '
			|| s_user_name
			|| ' IDENTIFIED BY '
			|| s_password
			|| ' DEFAULT TABLESPACE '
			|| s_tablespace_name
			|| ' TEMPORARY TABLESPACE '
			|| s_tmpspace_name
			|| ' QUOTA UNLIMITED ON '
			|| s_tablespace_name
			|| ' PROFILE '
			|| s_profile_name;
	END IF;

	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created user ''' || s_user_name || '''.');

	auth_array(1) := 'CREATE SESSION';
	auth_array(2) := 'CREATE TABLE';
	auth_array(3) := 'CREATE PROCEDURE';
	auth_array(4) := 'SELECT ANY DICTIONARY';
	auth_array(5) := 'SELECT ANY TABLE';
	auth_array(6) := 'INSERT ANY TABLE';
	auth_array(7) := 'DELETE ANY TABLE';
	auth_array(8) := 'UPDATE ANY TABLE';
	auth_array(9) := 'UNLIMITED TABLESPACE';

	n_loop_cnt := 1;
	WHILE n_loop_cnt <= auth_array.COUNT LOOP
		s_sql := 'GRANT '
			|| auth_array(n_loop_cnt)
			|| ' TO '
			|| s_user_name;
		EXECUTE IMMEDIATE s_sql;
		n_loop_cnt := n_loop_cnt + 1;
	END LOOP;

END;

--------------------------------------------------------------------------------
-- PROCEDURE create_table
--------------------------------------------------------------------------------
PROCEDURE create_table
IS
	s_sql VARCHAR2(1024);
	s_copytable_name VARCHAR2(64);
	s_synonym_name VARCHAR2(64);
	n_cnt PLS_INTEGER;
	n_loop_cnt PLS_INTEGER;

BEGIN
	n_loop_cnt := 1;
	WHILE n_loop_cnt <= table_array.COUNT LOOP

		s_copytable_name := s_user_name || '.COPY_' || table_array(n_loop_cnt).table_name;
		s_synonym_name := 'APPNAVI_' || table_array(n_loop_cnt).table_name;

		s_sql := 'CREATE TABLE '
			|| s_copytable_name
			|| ' TABLESPACE '
			|| s_tablespace_name
			|| ' AS SELECT '
			|| table_array(n_loop_cnt).column_name
			|| ' FROM '
			|| table_array(n_loop_cnt).table_name
			|| ' WHERE 0=1';
		EXECUTE IMMEDIATE s_sql;

		DBMS_OUTPUT.PUT_LINE('Successfully created table ''' || s_copytable_name || '''.');

		s_sql := 'CREATE OR REPLACE PUBLIC SYNONYM '
			|| s_synonym_name
			|| ' FOR '
			|| s_copytable_name;
		EXECUTE IMMEDIATE s_sql;

		DBMS_OUTPUT.PUT_LINE('Successfully created public synonym ''' || s_synonym_name || '''.');

		n_loop_cnt := n_loop_cnt + 1;

	END LOOP;

END;

--------------------------------------------------------------------------------
-- PROCEDURE create_global_temp_table (AppNavi 3.2.2)
--------------------------------------------------------------------------------
PROCEDURE create_global_temp_table
IS
	s_sql VARCHAR2(1024);
	s_copytable_name VARCHAR2(64);
	s_synonym_name VARCHAR2(64);
	n_cnt PLS_INTEGER;
	n_loop_cnt PLS_INTEGER;

BEGIN
	n_loop_cnt := 1;
	WHILE n_loop_cnt <= table_array.COUNT LOOP

		s_copytable_name := s_user_name || '.COPY_' || table_array(n_loop_cnt).table_name;
		s_synonym_name := 'APPNAVI_' || table_array(n_loop_cnt).table_name;

		s_sql := 'CREATE GLOBAL TEMPORARY TABLE '
			|| s_copytable_name
			|| ' ON COMMIT DELETE ROWS '
			|| ' AS SELECT '
			|| table_array(n_loop_cnt).column_name
			|| ' FROM '
			|| table_array(n_loop_cnt).table_name
			|| ' WHERE 0=1';
		EXECUTE IMMEDIATE s_sql;

		DBMS_OUTPUT.PUT_LINE('Successfully created table ''' || s_copytable_name || '''.');

		s_sql := 'CREATE OR REPLACE PUBLIC SYNONYM '
			|| s_synonym_name
			|| ' FOR '
			|| s_copytable_name;
		EXECUTE IMMEDIATE s_sql;

		DBMS_OUTPUT.PUT_LINE('Successfully created public synonym ''' || s_synonym_name || '''.');

		n_loop_cnt := n_loop_cnt + 1;

	END LOOP;

END;

--------------------------------------------------------------------------------
-- PROCEDURE create_appnavi_proc
--------------------------------------------------------------------------------
PROCEDURE create_appnavi_proc
IS
	s_sql VARCHAR2(20000);
	n_cnt PLS_INTEGER;

BEGIN
	-- create public synonym 'APPNAVI_PROC_COPYTABLE' --
	s_sql := 'CREATE OR REPLACE PUBLIC SYNONYM APPNAVI_PROC_COPYTABLE FOR '
		|| s_user_name
		|| '.APPNAVI_PROC_COPYTABLE001';
	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created public synonym ''APPNAVI_PROC_COPYTABLE''.');

	-- create procedure 'APPNAVI_PROC_COPYTABLE001' --
	s_sql := 'CREATE OR REPLACE PROCEDURE ' || s_user_name || '.APPNAVI_PROC_COPYTABLE001'
		|| ' IS '
		|| '     s_sql_proc VARCHAR2(1024);'
		|| ' BEGIN '
		         -- V$FILESTAT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$FILESTAT'
		|| '         SELECT FILE#, PHYBLKRD, PHYBLKWRT'
		|| '         FROM V$FILESTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$DATAFILE --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$DATAFILE'
		|| '         SELECT FILE#, NAME'
		|| '         FROM V$DATAFILE'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$TEMPSTAT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$TEMPSTAT'
		|| '         SELECT FILE#, PHYBLKRD, PHYBLKWRT'
		|| '         FROM V$TEMPSTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$TEMPFILE --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$TEMPFILE'
		|| '         SELECT FILE#, NAME'
		|| '         FROM V$TEMPFILE'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$PARAMETER --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$PARAMETER'
		|| '         SELECT NAME, VALUE'
		|| '         FROM V$PARAMETER'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
                 -- V$SGASTAT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$SGASTAT'
		|| '         SELECT NAME, POOL, BYTES'
		|| '         FROM V$SGASTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$PGASTAT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$PGASTAT'
		|| '         SELECT NAME, VALUE'
		|| '         FROM V$PGASTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$STATNAME --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$STATNAME'
		|| '         SELECT STATISTIC#, NAME'
		|| '         FROM V$STATNAME'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$SESSTAT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$SESSTAT'
		|| '         SELECT STATISTIC#, VALUE'
		|| '         FROM V$SESSTAT'
		|| '         WHERE STATISTIC# IN (SELECT STATISTIC# FROM V$STATNAME WHERE NAME IN (''''session pga memory'''', ''''session uga memory''''))'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$ROLLNAME --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$ROLLNAME'
		|| '         SELECT USN, NAME'
		|| '         FROM V$ROLLNAME'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$ROLLSTAT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$ROLLSTAT'
		|| '         SELECT USN, WAITS, GETS'
		|| '         FROM V$ROLLSTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$SORT_SEGMENT --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$SORT_SEGMENT'
		|| '         SELECT TABLESPACE_NAME, TOTAL_EXTENTS'
		|| '         FROM V$SORT_SEGMENT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$TEMP_EXTENT_POOL --
		|| '     s_sql_proc := ''INSERT INTO ' || s_user_name || '.COPY_V$TEMP_EXTENT_POOL'
		|| '         SELECT FILE_ID, BYTES_USED'
		|| '         FROM V$TEMP_EXTENT_POOL'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		|| ' END;';
	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created procedure ''' || s_user_name || '.APPNAVI_PROC_COPYTABLE001''.');

	s_sql := 'GRANT EXECUTE ON '
		|| s_user_name
		|| '.APPNAVI_PROC_COPYTABLE001 TO '
		|| s_user_name;
	EXECUTE IMMEDIATE s_sql;

	-- create public synonym 'APPNAVI_PROC_TRUNCATETABLE' --
	s_sql := 'CREATE OR REPLACE PUBLIC SYNONYM APPNAVI_PROC_TRUNCATETABLE FOR '
		|| s_user_name
		|| '.APPNAVI_PROC_TRUNCATETABLE001';
	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created public synonym ''APPNAVI_PROC_TRUNCATETABLE''.');

	-- create procedure 'APPNAVI_PROC_TRUNCATETABLE001' --
	s_sql := 'CREATE OR REPLACE PROCEDURE ' || s_user_name || '.APPNAVI_PROC_TRUNCATETABLE001'
		|| ' IS '
		|| '     s_sql_proc VARCHAR2(1024);'
		|| ' BEGIN '
		|| '     COMMIT;'
/*		         -- Do COMMIT instead of TRUNCATE TABLE. (AppNavi3.2.2) --
		         -- V$FILESTAT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$FILESTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$DATAFILE --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$DATAFILE'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$TEMPSTAT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$TEMPSTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$TEMPFILE --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$TEMPFILE'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$PARAMETER --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$PARAMETER'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
                 -- V$SGASTAT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$SGASTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$PGASTAT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$PGASTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$STATNAME --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$STATNAME'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$SESSTAT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$SESSTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$ROLLNAME --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$ROLLNAME'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$ROLLSTAT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$ROLLSTAT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$SORT_SEGMENT --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$SORT_SEGMENT'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
		         -- V$TEMP_EXTENT_POOL --
		|| '     s_sql_proc := ''TRUNCATE TABLE ' || s_user_name || '.COPY_V$TEMP_EXTENT_POOL'';'
		|| '     EXECUTE IMMEDIATE s_sql_proc;'
*/
		|| ' END;';
	EXECUTE IMMEDIATE s_sql;

	DBMS_OUTPUT.PUT_LINE('Successfully created procedure ''' || s_user_name || '.APPNAVI_PROC_TRUNCATETABLE001''.');

	s_sql := 'GRANT EXECUTE ON '
		|| s_user_name
		|| '.APPNAVI_PROC_TRUNCATETABLE001 TO '
		|| s_user_name;
	EXECUTE IMMEDIATE s_sql;

END;

--------------------------------------------------------------------------------
-- main
--------------------------------------------------------------------------------
BEGIN

	s_user_name			:= TRIM('&1');
	s_password			:= TRIM('&2');
	s_tablespace_name	:= TRIM('&3');
	s_datafile_name		:= TRIM('&4');
	s_tmpspace_name		:= TRIM('&5');
	s_profile_name		:= s_user_name || '_PROFILE';

	table_array(1).table_name := 'V$FILESTAT';
	table_array(2).table_name := 'V$DATAFILE';
	table_array(3).table_name := 'V$TEMPSTAT';
	table_array(4).table_name := 'V$TEMPFILE';
	table_array(5).table_name := 'V$PARAMETER';
	table_array(6).table_name := 'V$SGASTAT';
	table_array(7).table_name := 'V$PGASTAT';
	table_array(8).table_name := 'V$STATNAME';
	table_array(9).table_name := 'V$SESSTAT';
	table_array(10).table_name := 'V$ROLLNAME';
	table_array(11).table_name := 'V$ROLLSTAT';
	table_array(12).table_name := 'V$SORT_SEGMENT';
	table_array(13).table_name := 'V$TEMP_EXTENT_POOL';

	table_array(1).column_name := 'FILE#, PHYBLKRD, PHYBLKWRT';
	table_array(2).column_name := 'FILE#, NAME';
	table_array(3).column_name := 'FILE#, PHYBLKRD, PHYBLKWRT';
	table_array(4).column_name := 'FILE#, NAME';
	table_array(5).column_name := 'NAME, VALUE';
	table_array(6).column_name := 'NAME, POOL, BYTES';
	table_array(7).column_name := 'NAME, VALUE';
	table_array(8).column_name := 'STATISTIC#, NAME';
	table_array(9).column_name := 'STATISTIC#, VALUE';
	table_array(10).column_name := 'USN, NAME';
	table_array(11).column_name := 'USN, WAITS, GETS';
	table_array(12).column_name := 'TABLESPACE_NAME, TOTAL_EXTENTS';
	table_array(13).column_name := 'FILE_ID, BYTES_USED';

	DBMS_OUTPUT.PUT_LINE('--------------------------------------------------------------');

	-- check setup --
	SELECT COUNT(SYNONYM_NAME) INTO n_cnt FROM DBA_SYNONYMS WHERE UPPER(SYNONYM_NAME)='APPNAVI_PROC_COPYTABLE' AND UPPER(OWNER)='PUBLIC';
	IF n_cnt <> 0 THEN
		DBMS_OUTPUT.PUT_LINE('Error : OracleSetup.sql has already been executed.');
		RETURN;
	END IF;

	-- check user --
	IF LENGTHB(s_user_name) > 30 THEN
		DBMS_OUTPUT.PUT_LINE('Error : User name is too long. (Max 30 characters)');
		RETURN;
	END IF;
	
	SELECT COUNT(USERNAME) INTO n_cnt FROM DBA_USERS WHERE UPPER(USERNAME)=UPPER(s_user_name);
	IF n_cnt <> 0 THEN
		DBMS_OUTPUT.PUT_LINE('Error : User already exists.');
		RETURN;
	END IF;

	-- check profile --
	SELECT COUNT(PROFILE) INTO n_cnt FROM DBA_PROFILES WHERE UPPER(PROFILE)=UPPER(s_profile_name);
	IF n_cnt <> 0 THEN
		DBMS_OUTPUT.PUT_LINE('Error : Profile ''' || s_profile_name || ''' already exists.');
		RETURN;
	END IF;

	-- check password --
	IF s_password IS NULL THEN
		DBMS_OUTPUT.PUT_LINE('Error : Please specify the password.');
		RETURN;
	END IF;

	IF LENGTHB(s_password) > 30 THEN
		DBMS_OUTPUT.PUT_LINE('Error : Password is too long. (Max 30 characters)');
		RETURN;
	END IF;

	-- check tablespace/datafile --
	b_create_tablespace := FALSE;
	SELECT COUNT(TABLESPACE_NAME) INTO n_cnt FROM DBA_TABLESPACES WHERE UPPER(TABLESPACE_NAME)=UPPER(s_tablespace_name) AND UPPER(CONTENTS)='PERMANENT';
	IF n_cnt = 0 THEN
		SELECT COUNT(TABLESPACE_NAME) INTO n_cnt FROM DBA_TABLESPACES WHERE UPPER(TABLESPACE_NAME)=UPPER(s_tablespace_name);
		IF n_cnt <> 0 THEN
			DBMS_OUTPUT.PUT_LINE('Error : Tablespace ''' || s_tablespace_name || ''' is not parmanent tablespace.');
			RETURN;
		END IF;
		IF LENGTHB(s_tablespace_name) > 30 THEN
			DBMS_OUTPUT.PUT_LINE('Error : Tablespace name is too long. (Max 30 characters)');
			RETURN;
		END IF;
		IF s_datafile_name IS NULL THEN
			DBMS_OUTPUT.PUT_LINE('Error : Please specify the datafile of tablespace.');
			RETURN;
		END IF;
		b_create_tablespace := TRUE;
	END IF;

	-- check temporary tablespace --
	IF s_tmpspace_name IS NOT NULL THEN
		SELECT COUNT(TABLESPACE_NAME) INTO n_cnt FROM DBA_TABLESPACES WHERE UPPER(TABLESPACE_NAME)=UPPER(s_tmpspace_name) AND UPPER(CONTENTS)='TEMPORARY';
		IF n_cnt = 0 THEN
			SELECT COUNT(TABLESPACE_NAME) INTO n_cnt FROM DBA_TABLESPACES WHERE UPPER(TABLESPACE_NAME)=UPPER(s_tmpspace_name);
			IF n_cnt <> 0 THEN
				DBMS_OUTPUT.PUT_LINE('Error : Tablespace ''' || s_tmpspace_name || ''' is not temporary tablespace.');
			ELSE
				DBMS_OUTPUT.PUT_LINE('Error : Temporary tablespace ''' || s_tmpspace_name || ''' is not found.');
			END IF;
			RETURN;
		END IF;
	END IF;

	-- setup --
	IF b_create_tablespace = TRUE THEN
		create_tablespace();
	END IF;
	create_user();
	create_appnavi_proc();
/*	create_table();*/
	create_global_temp_table();

	DBMS_OUTPUT.PUT_LINE('Setup completed successfully.');

EXCEPTION
	WHEN OTHERS THEN
		DBMS_OUTPUT.PUT_LINE('Exception occurred.');
		DBMS_OUTPUT.PUT_LINE(SQLERRM);

END;
/
SET VERIFY ON
SET SERVEROUTPUT OFF
EXIT;
