SystemManagerG_setup_agent-ApplicationMonitor-Tomcat
=================================================

Description
-----------

This role sets to monitor agents registered in the topology view in SystemManager G with Tomcat. The user can store the setting in the location specified by this role and execute it for the agent server to set to monitor agents with Tomcat.

Requirements
------------

* This role must be executed on the server to be built with administrator authority. In Windows, create a playbook to execute this role as the user with administrator authority on the server to be built. In RHEL, create a playbook to execute this role as the root user on the server to be built.
* It is necessary to install Tomcat on the server to be built in advance.

Notes
-----

* Execute this role for the SystemManager G Tomcat monitoring agent server.
* Executing this role restarts Tomcat.

Role Variables
--------------

The variables used with this role are described below.
Use a playbook to specify the variables described in "Mandatory variables" and "Optional variables".

### Mandatory variables

Be sure to specify the following variables when executing this role.

#### VAR_SystemManagerG_Tomcat_Service_Name

Specify the Windows service name of the Tomcat.

#### VAR_SystemManagerG_Tomcat_startup_script_file_path

Specify the path name to the script file that starts Tomcat in the Linux environment.

#####  windows

The file path name for Windows cannot be specified.

#####  linux

Specify the file path name for Linux.

#### VAR_SystemManagerG_Tomcat_Registory_path

Specify the path name of the registry key in which the Tomcat optional parameter is defined.

### Optional variables

Specify the settings as needed.

#### VAR_SystemManagerG_Tomcat_startup_script_file_name

Specify the Tomcat startup shell name.
The default value is startup.sh.

#### VAR_SystemManagerG_Tomcat_Registory_variable

Specify the registry key name.
The default value is Options.

#### VAR_SystemManagerG_Tomcat_Registory_type

Specify the registry key type.
The default value is REG_MULTI_SZ.

#### VAR_SystemManagerG_Tomcat_Registory_data

Specify the Tomcat optional parameter.
Specify it on a single line including the existing settings. Use \0 as the line feed in registry data.

<Without authentication>
 -Dcom.sun.management.jmxremote.ssl=false
 -Dcom.sun.management.jmxremote.port=8999
 -Dcom.sun.management.jmxremote.authenticate=false

<With authentication>
 -Dcom.sun.management.jmxremote.ssl=false
 -Dcom.sun.management.jmxremote.port=8999
 -Dcom.sun.management.jmxremote.password.file=C:\Program Files\Java\jre7\lib\management\jmxremote.password
 -Dcom.sun.management.jmxremote.access.file=C:\Program Files\Java\jre7\lib\management\jmxremote.access

<Setting example>
-Dcatalina.home=C:\Program Files\Apache Software Foundation\Tomcat 7.0\0-Dcatalina.base=C:\Program Files\Apache Software Foundation\Tomcat 7.0\0-Djava.endorsed.dirs=C:\Program Files\Apache Software Foundation\Tomcat 7.0\endorsed\0-Djava.io.tmpdir=C:\Program Files\Apache Software Foundation\Tomcat 7.0\temp\0-Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager\0-Djava.util.logging.config.file=C:\Program Files\Apache Software Foundation\Tomcat 7.0\conf\logging.properties\0-Dcom.sun.management.jmxremote.ssl=false\0-Dcom.sun.management.jmxremote.port=8999\0-Dcom.sun.management.jmxremote.authenticate=false

#### VAR_SystemManagerG_Tomcat_Access_file_path

Specify the path name of access file.

#####  windows

Specify the file path name for Windows.

#####  linux

Specify the file path name for Linux.

#### VAR_SystemManagerG_Tomcat_Access_file_name

Specify the name of access file.
The default value is jmxremote.access.

#### VAR_SystemManagerG_Tomcat_Password_file_path

Specify the path name of password file.

#####  windows

Specify the file path name for Windows.

#####  linux

Specify the file path name for Linux.

#### VAR_SystemManagerG_Tomcat_Password_file_name

Specify the name of password file.
The default value is jmxremote.password.

#### VAR_SystemManagerG_Tomcat_UserName_dropped_access_rights

Specify the names of users from whom the password file access authority is removed in a list format.
By default, the following user is specified.
* Users
* SYSTEM
* Authenticated Users

#### VAR_SystemManagerG_agent_install_path

Specify the agent installation destination (installation path).

#####  windows

Specify the folder name for Windows.
If this is omitted, C:\Program Files (x86)\NEC\UMF\Operations is set.

#####  linux

Specify the folder name for Linux.
If this is omitted, /opt/UMF/Operations is set.

### Unchangeable variable

This parameter cannot be changed.

#### VAR_SystemManagerG_agent_collector_ini_file_name

This is the name of the configuration file for the Tomcat monitoring function. This file cannot be renamed.
The name is fixed to CollectorTomcat.ini.

#### VAR_SystemManagerG_agent_collector_file_name

This is the name of the configuration file for the application monitoring function. This file cannot be renamed.
The name is fixed to Collector.ini.

Dependencies
------------

SystemManagerG_common_agent_service_restart is used as the dependent role.

Usage
-----

1. Store the Tomcat monitoring definition file/Tomcat startup file/password file in the files/linux or files/windows directory for this role. When applying the monitoring definition file to the Windows agent, create it using the "character encoding: UTF-16LE (with BOM)/line feed code: CR+LF". When applying the monitoring definition file to the RHEL agent, create it using the "character encoding: UTF-8 (without BOM)/line feed code: LF".
The Tomcat startup file/password file must have the same character encoding and line feed code as those in the file on the target host.

    SystemManagerG_setup_agent-ApplicationMonitor-Tomcat
    |- files
    |  |- linux
    |  |  |- CollectorTomcat.ini
    |  |  |- Tomcat startup file
    |  |  |- Password file
    |  |- windows
    |  |  |- CollectorTomcat.ini
    |  |  |- Tomcat startup file
    |  |  |- Password file
    |  |  |- ...

2. Specify the agent installation folder name according to the OS type of target host.

3. Set the required variables for this role. For details, see "Role Variables".

4. Set optional variables for this role as needed. For details, see "Role Variables".

5. Execute a playbook.

Example Playbook
----------------

To install an agent and import the monitoring setting, store the provided role in the "role" directory and create the playbook described below.

    - hosts: monitoring_java_tomcat
      roles:
        - role: SystemManagerG_setup_agent-ApplicationMonitor-Tomcat

Troubleshooting
---------------

None

License
-------

Use this role within the scope of license of the main product.

Copyright
---------

Copyright (c) NEC Corporation 2017
