SystemManagerG_setup_manager-TopologyView
=========================================

Description
-----------

This role sets to monitor agents registered in the topology view in SystemManager G. The user can create a monitoring definition file, store it in the location specified by this role, and execute it for the manager server to set to monitor an agent.

Requirements
------------

* This role must be executed on the manager server with administrator authority. In Windows, create a playbook to execute this role as the user with administrator authority on the manager server. In RHEL, create a playbook to execute this role as the root user on the manager server.

Notes
-----

* Execute this role for the SystemManager G manager server.
* This role uses the TopologyCmd IMPORT command to set monitoring. Therefore, remote monitoring agents or agents registered in "Unregistered Host" cannot be set to be monitored. For other specifications and notes, see "Command Reference" (help differences) (TopologyCmdSgImpExp_Cmd.pdf), "TopologyCmd Monitoring Definition Batch Registration/Settings Check File Specifications" (TopologyCmdSgImpExp_File.pdf), and "Calendar Management - Schedule Management Import Definition File Reference" (Calendar_Schedule_Import.pdf).
* Run the command to acquire the definition mode while executing this role. While executing this role, do not acquire the definition mode for another operation. If the definition mode is acquired for another operation, execution of this role fails. For details about the definition mode, see "Monitoring window operating modes" in the SystemManager G manual.

Role Variables
--------------

The variables used with this role (defaults/main.yml) are described below.

### Mandatory variables

Be sure to specify the following variables when executing this role.

#### VAR_SystemManagerG_import_agent_list

Set monitoring in the mapping and sequence format.

 * name key
   * Specify the name of agent to which you want to apply the monitoring definition. Specify the agent name you specified during installation, the agent name displayed in the topology view, or the name displayed by running the TopologyCmd LIST command.

 * import key
   * Specify the relative path of the directory that contains the monitoring definition file with reference to the files/import directory for this role. Create a directory under an arbitrary name in the files/import directory for this role and store the monitoring definition file in it.

 * appmonitor key
   * Specify the name of the application enabled when setting the application management function in the monitoring definition file. The following values can be specified.
     * Oracle
     * IIS
     * SQLServer
     * WebLogicServer
     * PostgreSQL
     * WebOTX
     * Apache
     * Tomcat
     * SAP
     * SVF
     * JavaAP
     * WebSphere

In the following example, the MonitoringA and MonitoringB directories are created in the files/import directory for this role and the monitoring definition files are stored in these directories. The monitoring definition file stored in the MonitoringA directory is applied to AgentA while the monitoring definition file stored in the MonitoringB directory is applied to AgentB. Oracle and JavaAP are enabled and the monitoring definition file stored in the MonitoringA directory is applied to AgentC.

    SystemManagerG_setup_manager-TopologyView
    |- files
    |  |- import
    |  |  |- MonitorA
    |  |  |  |- Topology.txt
    |  |  |  |- Process.txt
    |  |  |  |- ...
    |  |  |- MonitorB
    |  |  |  |- Topology.txt
    |  |  |  |- Process.txt
    |  |  |  |- ...

    VAR_SystemManagerG_import_agent_list:
     - name: AgentA
       import: MonitorA
     - name: AgentB
       import: MonitorB
       appmonitor:
         - Oracle
         - JavaAP
     - name: AgentC
       import: MonitorA

You can also create an arbitrary subdirectory in the files/import directory for this role and store monitoring definition files in it.

    SystemManagerG_setup_manager-TopologyView
    |- files
    |  |- import
    |  |  |- SystemA
    |  |  |  |- MonitorA
    |  |  |  |  |- Topology.txt
    |  |  |  |  |- Process.txt
    |  |  |  |  |- ...
    |  |  |- SystemB
    |  |  |  |- MonitorB
    |  |  |  |  |- Topology.txt
    |  |  |  |  |- Process.txt
    |  |  |  |  |- ...

    VAR_SystemManagerG_import_agent_list:
     - name: AgentA
       import: SystemA/MonitorA
     - name: AgentB
       import: SystemB/MonitorB
       appmonitor:
         - Oracle
         - JavaAP
     - name: AgentC
       import: SystemA/MonitorA

If the OS of the manager server is Windows, use "\\" as the delimiter of the directory path specified with the import key.

    VAR_SystemManagerG_import_agent_list:
     - name: AgentA
       import: SystemA\\MonitiorA
     - name: AgentB
       import: SystemB\\MonitorB
       appmonitor:
         - IIS
         - Oracle
     - name: AgentC
       import: SystemA\\MonitorA

### Optional variables

You can optionally specify the following variables.

#### VAR_SystemManagerG_manager_install_path

You can specify the manager installation path.
If this variable is omitted, execution is performed assuming that the manager is installed in the following path:

* For Windows: %ProgramFiles(x86)%\NEC\UMF\Operations
* For RHEL: /opt/UMF/Operations

#### VAR_SystemManagerG_tmp_path

You can specify the temporary work directory used by this role.
The temporary work directory must have a free disk space to store monitoring definition files (in files for this role).

The specified directory is automatically created if it does not exist.
If this role normally terminates, the directory is automatically deleted.

If this variable is omitted, the following directory is used:

For Windows: %TEMP%\sysmgrg_ansible
For RHEL: /tmp/sysmgrg_ansible

#### VAR_SystemManagerG_import_agent_check_retries

This role checks whether the agent is connected to the manager before applying a monitoring definition.
This variable can specify how many times agent connection check is retried with an integer.
Usually it is not necessary to specify this variable.
If this variable is omitted, operation is performed with five times set to it.

#### VAR_SystemManagerG_import_agent_check_delay

This role checks whether the agent is connected to the manager before applying a monitoring definition.
This variable can specify the wait time until connection is retried if the agent is connected (in seconds) with an integer.
Usually it is not necessary to specify this variable.
If this variable is omitted, operation is performed with 60 seconds set to it.

Dependencies
------------

None

Usage
-----

1) Create a monitoring definition file according to "TopologyCmd Batch Registration and Setting Detail Confirmation of Monitoring Definitions File Specifications" and "Calendar Management and Schedule Management Import Definition File Reference". Or, export the monitoring definition of an existing agent from the topology view on the console to create a monitoring definition file. It is necessary to convert the characters code and line feed code in the monitoring definition file according to the OS type of the manager to which the file is applied. For details, see relevant documents.

2) Create a directory under an arbitrary name in the files/import directory for this role and store the monitoring definition file in it. For details, see "Role Variables".

3) When monitoring the 64-bit counter with IIS monitoring in the application management function, store CollectorObject.ini in the files/sg directory for this role. CollectorObject.ini is stored on the manager server and the manager service is restarted to apply the setting. For details about CollectorObject.ini, see "Preparing for IIS monitoring" in "SystemManager G Manual".

4) Set the required variables for this role. For details, see "Role Variables".

5) Set optional variables for this role as needed. For details, see "Role Variables".

6) Execute a playbook.

Sample Playbook
----------------

Store the provided role in the "roles" directory and create the playbook described below.

    - hosts: ManagerServer
      vars_files:
        - vars/main.yml
      roles:
        - role: SystemManagerG_setup_manager-TopologyView

Contents of vars/main.yml

    VAR_SystemManagerG_import_agent_list:
      - name: AgentA
        import: MonitorA
      - name: AgentB
        import: MonitorB
        appmonitor:
          - Oracle
          - JavaAP
      - name: AgentC
        import: MonitorA

To install an agent and set to monitor it, store the provided role in the "roles" directory and create the playbook described below. Agents registered in "Unregistered Host" cannot be set to be monitored by using this role. So, set them to belong to the topology view group with the role used for installation.

    - hosts: AgentServers
      vars_files:
        - vars/install.yml
      roles:
        - role: SystemManagerG_install_agent

    - hosts: ManagerServer
      vars_files:
        - vars/setup.yml
      roles:
        - role: SystemManagerG_setup_manager-TopologyView

Contents of vars/install.yml

    VAR_SystemManagerG_agent_install_type: normal
    VAR_SystemManagerG_manager_name: ManagerServer
    VAR_SystemManagerG_agent_topology_group: GroupA

Contents of vars/setup.yml

    VAR_SystemManagerG_import_agent_list:
      - name: AgentA
        import: MonitorA
      - name: AgentB
        import: MonitorB
        appmonitor:
          - Oracle
          - JavaAP
      - name: AgentC
        import: MonitorA

Troubleshooting
---------------

#### TASK [Create the temporary directory] fails.

It failed to create the temporary work directory specified with VAR_SystemManagerG_tmp_path.
Check whether the specified path is correct.

#### TASK [Check for the existance of agents] fails.

It failed to confirm the presence of the agent specified with VAR_SystemManagerG_import_agent_list.
* Check whether the manager path specified with VAR_SystemManagerG_manager_install_path (default value if omitted) is correct.
* Check whether the agent name specified with VAR_SystemManagerG_import_agent_list is correct.
* Check whether the agent specified with VAR_SystemManagerG_import_agent_list is connected to the manager on the console.

#### TASK [Import template file to the agent] fails.

It failed to apply the monitoring definition file specified with VAR_SystemManagerG_import_agent_list.
* Check whether the directory specified with VAR_SystemManagerG_import_agent_list contains monitoring definition files.
* Check whether the format, characters code, and line feed code of monitoring definition file are correct.


License
-------

Use this role within the scope of license of the main product.

Copyright
---------

Copyright (c) NEC Corporation 2017
